========================
Henson-S3 |build status|
========================

.. |build status| image:: https://travis-ci.org/dirn/Henson-S3.svg?branch=master
   :target: https://travis-ci.org/dirn/Henson-S3

A library for easily using S3 in a Henson application.

* `Documentation <https://henson-s3.readthedocs.io>`_
* `Installation <https://henson-s3.readthedocs.io/en/latest/#installation>`_
* `Changelog <https://henson-s3.readthedocs.io/en/latest/changes.html>`_
* `Source <https://github.com/dirn/Henson-S3>`_
